==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/CustomMessagesServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.ICustomMessagesService;
import pt.digitalis.dif.dem.managers.impl.model.data.CustomMessages;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class CustomMessagesServiceImpl implements ICustomMessagesService {

    /**
     * Obtains a new DataSet for the CustomMessages entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<CustomMessages> getCustomMessagesDataSet() {
        return new HibernateDataSet<CustomMessages>(CustomMessages.class, HibernateUtil.getSessionFactory("DIFRepository"),
                CustomMessages.getPKFieldListAsString(), CustomMessages.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == CustomMessages.class)
            return getCustomMessagesDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(CustomMessages.class.getSimpleName()))
            return getCustomMessagesDataSet();

        return null;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/CustomMessagesServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.ICustomMessagesService;
import pt.digitalis.dif.dem.managers.impl.model.data.CustomMessages;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class CustomMessagesServiceImpl implements ICustomMessagesService {

    /**
     * Constant with the session factory ID
     */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /**
     * Obtains a new DataSet for the CustomMessages entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<CustomMessages> getCustomMessagesDataSet() {
        return new HibernateDataSet<CustomMessages>(CustomMessages.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                CustomMessages.getPKFieldListAsString(), CustomMessages.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == CustomMessages.class)
            return getCustomMessagesDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(CustomMessages.class.getSimpleName()))
            return getCustomMessagesDataSet();

        return null;
    }
}
